import 'dart:convert';

import 'package:mobx/mobx.dart';
import 'package:models_base/src/common/photo_source.dart';

abstract class ArticleAbstract {
  final int lineId;
  int get productId => lineId;
  final int id;
  final String fullName;

  final double weight;
  final int? articleCode;
  final String? photo;
  final PhotoSource photoSource;
  @observable
  final bool status;
  final DateTime? creationDate;
  final DateTime? updateDate;

  const ArticleAbstract({
    required this.lineId,
    required this.id,
    required this.fullName,
    this.weight = 1.0,
    required this.creationDate,
    required this.updateDate,
    this.articleCode,
    this.photo,
    this.photoSource = PhotoSource.unknown,
    required this.status,
  });

  String nameWithoutProductPart(String productTitle) {
    String name;
    if (productTitle.length < fullName.length &&
        fullName.contains(productTitle)) {
      name = fullName.substring(productTitle.length);
    } else {
      name = fullName;
    }
    return name.trim();
  }

  @override
  String toString() {
    return """
Article(
  lineId: $lineId,
  id: $id,
  fullName: '$fullName',
  creationDate: $creationDate,
  updateDate: $updateDate,
  weight: $weight,
  articleCode: $articleCode,
  photo: $photo,
  photoSource: $photoSource,
  status: $status,
)
""";
  }

  Map<String, dynamic> toMap() {
    return {
      'lineId': lineId,
      'id': id,
      'fullName': fullName,
      'weight': weight,
      'articleCode': articleCode ?? 0,
      'photo': photo ?? '',
      'photoSource': photoSource,
      'creationDate': creationDate?.toIso8601String(),
      'updateDate': updateDate?.toIso8601String(),
      'status': status,
    };
  }

  String toJson() => json.encode(toMap());

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) return true;

    return other is ArticleAbstract &&
        other.lineId == lineId &&
        other.id == id &&
        other.fullName == fullName &&
        other.weight == weight &&
        other.articleCode == articleCode &&
        other.photo == photo &&
        other.creationDate == creationDate &&
        other.updateDate == updateDate &&
        other.status == status;
  }

  @override
  int get hashCode {
    return lineId.hashCode ^
        id.hashCode ^
        fullName.hashCode ^
        weight.hashCode ^
        articleCode.hashCode ^
        photo.hashCode ^
        creationDate.hashCode ^
        updateDate.hashCode ^
        status.hashCode;
  }
}
